'use strict';

angular.module('datasid.attendance.search', []).
    config(function($stateProvider, $httpProvider) {
        $stateProvider.
            state('attendance.search', {
                url: '/search',
                controller: 'SearchCtrl',
                templateUrl: 'partials/search.html',
                section: 'attendance'
            });
    }).

    filter('projectStr', function () {
        return function(input) {
            if (input == 0)
                return 'Telecentros BR';
            if (input == 1)
                return 'GESAC';
            if (input == 2)
                return 'Cidades Digitas';
            else
                return 'Desconhecido';
        };
    }).

    filter('filterResults', function () {
        return function(input, scope) {
            var ret = [];

            angular.forEach(input, function (item) {
                var push = true;

                angular.forEach(scope.filters, function (filter) {
                    var val = item[filter.key],
                        match = false,
                        empty = true;

                    angular.forEach(filter.options, function (option) {
                        if (option.value) {
                            empty = false;

                            if (val === option.key) {
                                match = true;
                                return;
                            }
                        }
                    });

                    if ((!empty) && (!match))
                        push = false;
                });

                if (push)
                    ret.push(item);
            });

            return ret;
        };
    }).

    factory('PointsFactory', function($resource) {
        return $resource('/api/points', {}, {
            list: {method: 'POST', isArray: true},
            count: {method: 'POST', url: '/api/points/count'}
        });
    }).

    controller('SearchCtrl', function ($scope, $rootScope, PointsFactory) {
        $scope.points = [];

        $scope.sorting = 'name';

        $scope.filters = [
            {
                key: 'project',
                title: 'Projeto',
                options: [
                    { key: 'TLBR', title: 'TLBR', value: true },
                    { key: 'TLBR/GESAC', title: 'TLBR/GESAC', value: true },
                    { key: 'GESAC', title: 'GESAC', value: true },
                    { key: 'Cidades Digitais', title: 'Cidades Digitais', value: true }
                ],
                more: false
            },
            {
                key: 'location',
                title: 'Localização',
                options: [
                    { key: 3106200, title: 'Belo Horizonte, MG', value: false },
                    { key: 2927408, title: 'Salvador, BA', value: false },
                    { key: 1501402, title: 'Belém, PA', value: false },
                    { key: 5300108, title: 'Brasília, DF' , value: false }
                ],
                more: true
            }
        ];
        $scope.compiledFilters = {};

        $scope.currentPage = 0;
        $scope.pageCount = 0;
        $scope.pages = [];
        $scope.collapsedPages = {lower: false, upper: false};

        var pageUpdate = function () {
            if ($scope.currentPage > $scope.pageCount)
                $scope.currentPage = $scope.pageCount;

            var lowerBound = $scope.currentPage - 5,
                upperBound = $scope.currentPage + 5;

            $scope.collapsedPages.lower = true;
            if (lowerBound <= 0) {
                upperBound += -lowerBound;
                $scope.collapsedPages.lower = false;
                lowerBound = 0;
            }

            $scope.collapsedPages.upper = true;
            if (upperBound >= $scope.pageCount) {
                lowerBound -= upperBound - $scope.pageCount;
                $scope.collapsedPages.upper = false;
                upperBound = $scope.pageCount;
            }

            $scope.pages = [];
            for (var i=lowerBound; i<upperBound; i++)
                $scope.pages.push(i);
        };
        $scope.$watch('pageCount', pageUpdate);
        $scope.$watch('currentPage', pageUpdate);

        $scope.jumpTo = function (page) {
            if ($scope.currentPage == page)
                return;

            $scope.currentPage = page;

            $scope.points = PointsFactory.list({
                sorting: $scope.sorting,
                page: $scope.currentPage,
                filters: $scope.compiledFilters
            });
        };

        $scope.setSorting = function (column) {
            if ($scope.sorting === column)
                $scope.sorting = '-' + column;
            else
                $scope.sorting = column;

            $scope.currentPage = 0;

            $scope.points = PointsFactory.list({
                sorting: $scope.sorting,
                page: $scope.currentPage,
                filters: $scope.compiledFilters
            });
        };

        $scope.updateFilters = function () {
            $scope.compiledFilters = {};

            for (var i=0; i < $scope.filters.length; i++) {
                var filter = $scope.filters[i];

                $scope.compiledFilters[filter.key] = [];
                for (var j=0; j < filter.options.length; j++) {
                    if (filter.options[j].value)
                        $scope.compiledFilters[filter.key].push(filter.options[j].key);
                }
            }

            $scope.currentPage = 0;

            PointsFactory.count({
                sorting: $scope.sorting,
                page: $scope.currentPage,
                filters: $scope.compiledFilters
            }, function (res) {
                $scope.pageCount = res.pageCount || 0;
            });

            $scope.points = PointsFactory.list({
                sorting: $scope.sorting,
                page: $scope.currentPage,
                filters: $scope.compiledFilters
            });
        };

        $scope.updateFilters();
    });