var DefaultCharts = {
    barChart: {
        chart: {
            backgroundColor: null,
            height: '300',
            defaultSeriesType: 'column'
        },
        colors: [
            '#a9c33c',
            '#eeba28',
            '#c3252e',
        ],
        title: {
            text: ''
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        xAxis: {
            categories: [],
            labels: {
                style: {
                    fontSize: '11px'
                },
                formatter: function() {
                    return '<a onclick="Charts.click(\''+this.value[0]+'\');" style="color: #08C; cursor: pointer">' + this.value[1] + '</a>';
                },
                rotation: 0
            },
        },
        yAxis: {
            min: 0,
            title: {
                text: 'Número de Máquinas'
            },
            labels: {
                formatter: function() {
                    return formatNumber(this.value);
                }
            }
        },
        credits: {
            enabled: false
        },
        legend: {
            enabled: false
        },
        tooltip: {
            shared: true,
            formatter: function() {
                var s = '<b>'+ this.x[1] +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span>' +
                        point.series.name + '</span>: ' + formatNumber(point.y) + ' máquinas';
                };

                return s;
            },
            positioner: function() {
                return {x: 2, y: 2};
            }
        },
        plotOptions: {
            series: {
                groupPadding: 0.15,
                pointPadding: 0,
                cursor: 'pointer'
            }
        },
        series: [
            {name: 'Menos de 10 dias'},
            {name: 'Entre 11 e 30 dias'},
            {name: 'Mais de 30 dias'}
        ]
    },

    pieChart: {
        chart: {
            type: 'pie',
            backgroundColor: null,
            height: '300',
        },
        colors: [
            '#a9c33c',
            '#eeba28',
            '#c3252e',
        ],
        title: {
            text: ''
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            formatter: function() {
                return '<b>' + this.key.replace('\n', ' ') + '</b><br/>' + formatNumber(this.y) + ' máquinas'
            }
        },
        plotOptions: {
            pie: {
                dataLabels: {
                    enabled: true,
                    distance: 5,
                    connectorWidth: 0,
                    formatter: function() {
                        return '<b>'+ this.point.name.split('\n').join('</b><br/><b>') +
                               '</b><br/>' + Math.round(this.percentage) + '%';
                    }
                }
            }
        },
        series: [
            {data: [
                ['Menos de\n10 dias', 0],
                ['Entre 11\ne 30 dias', 0],
                ['Mais de\n30 dias', 0]
            ]}
        ]
    },

    histChart: {
        chart: {
            type: 'line',
            backgroundColor: null,
            height: '300',
        },
        colors: [
            '#a9c33c',
            '#eeba28',
            '#c3252e',
        ],
        title: {
            text: 'Histórico dos Últimos 6 meses'
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        xAxis: {
            categories: []
        },
        yAxis: {
            min: 0,
            title: {
                text: 'Número de Máquinas'
            },
            labels: {
                formatter: function() {
                    return formatNumber(this.value);
                }
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            crosshairs: {
                width: 2,
                color: 'gray',
                dashStyle: 'shortdot'
            },
            formatter: function() {
                var s = '<b>'+ this.x +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span>' +
                        point.series.name + '</span>: ' + formatNumber(point.y) + ' máquinas';
                };

                return s;
            },
            positioner: function () {
                return { x: 10, y: 10 };
            },
            shared: true
        },
        plotOptions: {
            series: {
                groupPadding: 0.05
            }
        },
        legend: {
            layout: 'vertical',
            itemMarginTop: 3,
            itemMarginBottom: 3
        },
        series: [
            {name: 'Último contato há menos de 10 dias'},
            {name: 'Último contato entre 11 e 30 dias'},
            {name: 'Último contato há mais de 30 dias'}
        ]
    },

    netusageChart: {
        chart: {
            height: 550,
        },
        colors: [
            '#2f7ed8',
            '#0d233a'
        ],
        rangeSelector : {
            selected : 1,
            inputDateFormat: '%d/%m/%Y',
            buttonTheme: {
                width: 75,
            },
            buttons: [{
                type: 'day',
                count: 1,
                text: 'Diário'
            }, {
                type: 'week',
                count: 1,
                text: 'Semanal'
            }, {
                type: 'month',
                count: 1,
                text: 'Mensal'
            }, {
                type: 'month',
                count: 6,
                text: 'Semestral'
            }, {
                type: 'year',
                count: 1,
                text: 'Anual'
            }]
        },
        plotOptions: {
            line: {
                gapSize: 1,
                connectNulls: false,
            }
        },
        xAxis: {
            type: 'datetime',
            ordinal: false,
            dateTimeLabelFormats: {
                second: '%d/%m/%Y<br/>%H:%M:%S',
                minute: '%d/%m/%Y<br/>%H:%M',
                hour: '%d/%m/%Y<br/>%H:%M',
                day: '%d/%m/%Y',
                week: '%d/%m/%Y',
                month: '%Y<br/>%b',
                year: '%Y'
            },
            tickPixelInterval: 200
        },
        yAxis: {
            gridLineDashStyle: 'dash',
            gridLineColor: '#ddd',
            alternateGridColor: '#f3faff',
            minRange: 1024,
            min: 0,
            allowDecimals: false,
            labels: {
                formatter: function() {
                    return formatKBits(this.value);
                }
            }
        },
        navigator: {
            height: 60,
            xAxis: {
                dateTimeLabelFormats: {
                    second: '%d/%m/%Y',
                    minute: '%d/%m/%Y',
                    hour: '%d/%m/%Y',
                    day: '%d/%m/%Y',
                    week: '%d/%m/%Y',
                    month: '%m/%Y',
                    year: '%Y'
                }
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            crosshairs: {
                width: 2,
                color: 'gray',
                dashStyle: 'shortdot'
            },
            formatter: function() {
                var s = '<b>'+ formatDate(new Date(this.x)) +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span>' +
                        point.series.name + '</span>: ' + formatKBits(point.y);
                };

                return s;
            },
            shared: true
        },
        legend: {
            enabled: true
        },
        series : [{
            name : 'Download',
            data: [],
            pointInterval: 5 * 1000,
            dataGrouping: {
                enabled: false
            },
        }, {
            name : 'Upload',
            data: [],
            pointInterval: 5 * 1000,
            dataGrouping: {
                enabled: false
            },
        }]
    }
};